Gemeinde Adressverwaltung GUI: Gemeinde.Login Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Öffentliche Attribute | Aufstellung aller Elemente
Gemeinde.Login Klassenreferenz
Klassendiagramm für Gemeinde.Login:
[Legende]
Zusammengehörigkeiten von Gemeinde.Login:
[Legende]

## Öffentliche Methoden
def | __init__ (self)
def | activateLogin (self)
def | activateGemeinde (self)
def | handleLogin (self)
def | handleSelectGemeinde (self, event)
def | handleCancel (self)

## Öffentliche Attribute
| lblUser
| lblPassword
| lblGemeinde
| varUser
| varPassword
| entUser
| entPassword
| frmGemeinde
| btnLogin
| btnCancel

## Ausführliche Beschreibung

    Login - Dialog nur zum Login und zur Auswahl der Gemeinde

        Wird vor der Main-Anwendung gestartet und sorgt dafür, dass der User sich
        erfolgreich einlogged und anschließend die Gemeinde auswählt.

## Dokumentation der Elementfunktionen

## ◆ activateGemeinde()

def Gemeinde.Login.activateGemeinde | ( |  | self | ) |

    activateGemeinde - Hält den User auf der Gemeinde-Auswahl

        Aktiviert die Gemeinde-Auswahl und deaktiviert die Login-Widgets

## ◆ activateLogin()

def Gemeinde.Login.activateLogin | ( |  | self | ) |

    activateLogin - Hält den User auf den Login-Feldern

        Aktiviert die Login-Widgets und deaktiviert die Gemeinde-Auswahl

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde.py